#
# spec file for package layer-shell-qt
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2021 Fabian Vogt
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Full Plasma 5 version (e.g. 5.8.95)
%{!?_plasma5_bugfix: %define _plasma5_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 5.8 in KF5, but 5.8.95 in KUF)
%{!?_plasma5_version: %define _plasma5_version %(echo %{_plasma5_bugfix} | awk -F. '{print $1"."$2}')}

%bcond_without released
Name:           layer-shell-qt
Version:        5.27.4
Release:        bp155.1.7
Summary:        wlr-layer-shell integration for Qt
License:        LGPL-3.0-or-later
Group:          Development/Libraries/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/layer-shell-qt-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/layer-shell-qt-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  cmake >= 3.16
BuildRequires:  extra-cmake-modules
BuildRequires:  kf5-filesystem
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libqt5-qtwayland-private-headers-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5Gui) >= 5.15.0
BuildRequires:  cmake(Qt5Qml)
BuildRequires:  cmake(Qt5WaylandClient)
BuildRequires:  cmake(Qt5XkbCommonSupport)
# Workaround missing requirement in libQt5Gui-private-headers-devel
BuildRequires:  pkgconfig(xkbcommon) >= 0.4.1
BuildRequires:  pkgconfig(wayland-client) >= 1.3.0
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-server) >= 1.3.0

%description
This allows integration of Qt applications with wlr-layer-shell.

%package -n layer-shell-qt5
Summary:        wlr-layer-shell integration for Qt 5
Group:          Development/Libraries/KDE

%description -n layer-shell-qt5
This allows integration of Qt applications with wlr-layer-shell.

%package -n layer-shell-qt5-devel
Summary:        wlr-layer-shell integration for Qt 5 - development files
Group:          Development/Libraries/KDE
Requires:       layer-shell-qt5 = %{version}
Requires:       libqt5-qtwayland-private-headers-devel
Requires:       cmake(Qt5Qml)
Requires:       pkgconfig(wayland-client) >= 1.3.0

%description -n layer-shell-qt5-devel
This allows integration of Qt applications with wlr-layer-shell.

%prep
%autosetup -p1

%build
# Qt5XkbCommonSupportPrivate doesn't link publicly against xkbcommon
export CXXFLAGS="%optflags $(pkg-config xkbcommon --cflags)"
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%post -n layer-shell-qt5 -p /sbin/ldconfig
%postun -n layer-shell-qt5 -p /sbin/ldconfig

%files -n layer-shell-qt5
%license LICENSES/*.txt
%{_kf5_plugindir}/wayland-shell-integration/liblayer-shell.so
%{_kf5_libdir}/libLayerShellQtInterface.so.5
%{_kf5_libdir}/libLayerShellQtInterface.so.%{_plasma5_bugfix}

%files -n layer-shell-qt5-devel
%{_kf5_libdir}/libLayerShellQtInterface.so
%{_kf5_libdir}/cmake/LayerShellQt/
%{_includedir}/LayerShellQt/

%changelog
* Tue Apr  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.4
- No code changes since 5.27.3
* Tue Mar 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.3
- No code changes since 5.27.2
* Tue Feb 28 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.2
- Changes since 5.27.1:
  * Use the QScreen of the QWindow as default output
* Tue Feb 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.1
- No code changes since 5.27.0
* Thu Feb  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.0
- No code changes since 5.26.90
* Thu Jan 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.90
- Changes since 5.26.5:
  * Use ecm_set_disabled_deprecation_versions
* Wed Jan  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.5
- No code changes since 5.26.4
* Tue Nov 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.4
- No code changes since 5.26.3
* Tue Nov  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.3
- No code changes since 5.26.2
* Wed Oct 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.2
- No code changes since 5.26.1
* Tue Oct 18 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.1
- No code changes since 5.26.0
* Thu Oct  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.0
- No code changes since 5.25.90
* Thu Sep 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.90
- Changes since 5.25.5:
  * Add FreeBSD Qt6 CI support
  * Make fully reuse compliant
  * Use change signals on Window interface class.
  * Mark required deps as required (kde#454912)
* Tue Sep  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.5
- No code changes since 5.25.4
* Tue Aug  2 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.4
- No code changes since 5.25.3
* Tue Jul 12 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.3
- No code changes since 5.25.2
* Tue Jun 28 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.2
- No code changes since 5.25.1
* Tue Jun 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.1
- No code changes since 5.25.0
* Thu Jun  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.0
- Changes since 5.24.90:
  * Mark required deps as required (kde#454912)
* Thu May 19 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.90
- Changes since 5.24.5:
  * Minor api doc improvement for api.kde.org
  * Build with Qt6
  * Add desiredScreen property to LayerShellQt::Window
* Tue May  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.5
- No code changes since 5.24.4
* Tue Mar 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.4
- No code changes since 5.24.3
* Tue Mar  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.3
- No code changes since 5.24.2
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.2
- No code changes since 5.24.1
* Tue Feb 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.1
- No code changes since 5.24.0
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.0
- No code changes since 5.23.90
* Thu Jan 13 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.90
- Changes since 5.23.5:
  * Add FreeBSD CI
  * Add Linux CI
  * Add .kde-ci.yml
* Tue Jan  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.5
- No code changes since 5.23.4
* Tue Nov 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.4
- No code changes since 5.23.3
* Tue Nov  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.3
- No code changes since 5.23.2
* Tue Oct 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.2
- No code changes since 5.23.1
* Tue Oct 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.1
- No code changes since 5.23.0
* Thu Oct  7 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.0
- No code changes since 5.22.90
- Add new key + signature to plasma.keyring
* Thu Sep 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.90
- Changes since 5.22.5:
  * Fix a crash when creating views on the placeholder screen
  * Explicitly set KDE_COMPILERSETTINGS_LEVEL
  * Fix compile with last ecm.
  * Mark .gitignore file as non-copyrightable
* Tue Aug 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.5
- No code changes since 5.22.4
* Tue Jul 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.4
- No code changes since 5.22.3
* Tue Jul  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.3
- No code changes since 5.22.2.1
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.2.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.2
- No code changes since 5.22.1
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.1
- No code changes since 5.22.0
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- No code changes since 5.21.90
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New part of Plasma
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
- No code changes since 5.21.5
* Thu Apr  1 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Initial commit
